# -*- coding: utf-8 -*-

import pymel.core as pm
from cwmaya.tabs.base_tab import BaseTab
from cwmaya.widgets.single_option_menu import SingleOptionMenuControl
from cwmaya.widgets.text_area import TextAreaControl

class JobTab(BaseTab):
    
    def __init__(self):
        
        self.label_ctl = None
        self.project_name_ctl = None
        self.description_ctl = None
        self.metadata_ctl = None
        
        self.chunk_size_ctl = None
        self.custom_frames_ctl = None
        self.scout_frames_ctl = None
        self.frame_range_ctl = None
        
        
        super(JobTab, self).__init__()
        self.build_ui()
        
    def build_ui(self):
        
        pm.setParent(self.column)
        frame = pm.frameLayout(label="General", collapsable=True, collapse=False)
        self.label_ctl =  self.create_text_control("Job label")
        pm.setParent(frame)
        self.description_ctl = self.create_description_control()
        pm.setParent(frame)
        self.project_name_ctl = self.create_project_control()
        pm.setParent(self.column)
        
        frame = pm.frameLayout(label="Frames", collapsable=True, collapse=False)
        self.chunk_size_ctl = self.create_int_control("Chunk size")
        pm.setParent(frame)
        self.custom_frames_ctl = self.create_hidable_text_control("Custom frames")
        pm.setParent(frame)
        self.scout_frames_ctl = self.create_hidable_text_control("Scout frames")
        pm.setParent(self.column)
        pm.frameLayout(label="Metadata", collapsable=True, collapse=False)
        self.metadata_ctl = self.create_kvpairs_control()

    def bind(self, node):
        self.bind_job_node(node)
        self.bind_frames(node)
        
    def bind_job_node(self, node):
        self.label_ctl.bind(node.attr("label"))
        self.description_ctl.bind(node.attr("description"))
        self.metadata_ctl.bind(node.attr("metadata"))
        self.project_name_ctl.bind(node.attr("projectName"))
        
    def bind_frames(self, node):
        self.chunk_size_ctl.bind(node.attr("chunkSize"))
        self.custom_frames_ctl.bind(
            node.attr("useCustomRange"), node.attr("customRange")
        )
        self.scout_frames_ctl.bind(
            node.attr("useScoutFrames"), node.attr("scoutFrames")
        )

 
    def create_description_control(self):
        result = TextAreaControl()
        result.set_label("Description")
        return result
 
    def create_project_control(self):
        result = SingleOptionMenuControl()
        result.set_label("Project")
        return result
    
    def hydrate_data_models(self, **kwargs):
        """Hydrate the coredata for this node."""
        projects_model = kwargs.get("projects_model")
        self.project_name_ctl.hydrate(projects_model)