import pymel.core as pm

from cwmaya.tabs.base_tab import BaseTab
from cwmaya.widgets.dual_option_menu import DualOptionMenuControl
from cwmaya.widgets.software_stack_control import SoftwareStackControl



class TaskTab(BaseTab):

    def __init__(self):
        """
        Create the UI.
        """
        # Common task UI
        self.label_ctl = None
        self.commands_ctl = None
        self.extra_assets_ctl = None
        self.environment_ctl = None
        self.output_path_ctl = None
        self.software_ctl = None
        self.hardware_ctl = None

        super(TaskTab, self).__init__()

    def build_ui(self):
        
        pm.setParent(self.column)
        self.label_ctl = self.create_text_control("Label")
        pm.setParent(self.column)
        pm.frameLayout(label="Commands", collapsable=True, collapse=False)
        pm.setParent(self.column)
        self.commands_ctl = self.create_commands_control()
        pm.setParent(self.column)
        self.output_path_ctl = self.create_output_path_control() 
        pm.setParent(self.column)
        pm.frameLayout(label="Extra assets", collapsable=True, collapse=False)
        self.extra_assets_ctl = self.create_extra_assets_control()
        pm.setParent(self.column)
        
        pm.setParent(self.column)
        advanced = pm.frameLayout(label="Advanced", collapsable=True, collapse=True)
        pm.setParent(advanced)
        pm.frameLayout(label="Environment", collapsable=True, collapse=False)
        self.environment_ctl = self.create_kvpairs_control()
        pm.setParent(advanced)
        pm.frameLayout(label="Hardware", collapsable=True, collapse=False)
        self.hardware_ctl = self.create_hardware_control()
        pm.setParent(advanced)
        pm.frameLayout(label="Software", collapsable=True, collapse=False)
        self.software_ctl = self.create_software_control()
        pm.setParent(self.column)
        
        

    def bind(self, node, prefix):

        if not prefix:
            raise ValueError("prefix must be set.")
        self.label_ctl.bind(node.attr(f"{prefix}Label"))

        self.environment_ctl.bind(node.attr(f"{prefix}Environment"))
        self.extra_assets_ctl.bind(node.attr(f"{prefix}ExtraAssets"))
        self.commands_ctl.bind(node.attr(f"{prefix}Commands"))
        self.output_path_ctl.bind(node.attr(f"{prefix}OutputPath"))
        self.software_ctl.bind(node.attr(f"{prefix}Software"))
        self.hardware_ctl.bind(node.attr(f"{prefix}Hardware"))

    def hydrate_data_models(self, **kwargs):
        hardware_model = kwargs.get("hardware_model")
        packages_model = kwargs.get("packages_model")

        self.software_ctl.hydrate(packages_model)
        self.hardware_ctl.hydrate(hardware_model)

    @staticmethod
    def create_hardware_control():
        result = DualOptionMenuControl()
        return result

    @staticmethod
    def create_software_control():
        result = SoftwareStackControl()
        return result