# from __future__ import unicode_literals
import os
import json

from cwmaya.helpers import assets, context, frames_attributes, job_attributes, python_script_attributes, task_attributes
from cwmaya.template.base.node import cwSubmissionNode
from cwmaya.helpers import (
    upload_helpers,
)
from cwstorm.dsl.cmd import Cmd

# pylint: disable=import-error
import maya.api.OpenMaya as om


def maya_useNewAPI():
    pass


class cwFlatNode(cwSubmissionNode):

    # Declare
    aRenderTask = None
    aFramesAttributes = None

    id = om.MTypeId(0x880503)

    def __init__(self):
        """Initialize the class."""
        super(cwFlatNode, self).__init__()

    @staticmethod
    def creator():
        return cwFlatNode()

    @classmethod
    def isAbstractClass(cls):
        return False

    @classmethod
    def initialize(cls):
        """Create the static attributes."""
        om.MPxNode.inheritAttributesFrom("cwSubmissionNode")
        cls.aRenderTask = task_attributes.initialize("rnd", "rd", cls.aOutput)
        cls.aFramesAttributes = frames_attributes.initialize(cls.aOutput, cls.aTokens)

    def compute(self, plug, data):
        """Compute the output json from the input attributes."""
        return super(cwFlatNode, self).compute(plug, data)

    def computeTokens(self, data):
        """Compute output json from input attributes."""
        sequences = frames_attributes.getSequences(data, self.aFramesAttributes)
        this_node = om.MFnDependencyNode(self.thisMObject())
        static_context = context.getStatic(this_node, sequences)
        chunk = sequences["main_sequence"].chunks()[0]
        dynamic_context = context.getDynamic(static_context, chunk)
        result = json.dumps(dynamic_context)
        return result

    def computeJob(self, data):
        """Compute output json from input attributes."""

        sequences = frames_attributes.getSequences(data, self.aFramesAttributes)
        this_node = om.MFnDependencyNode(self.thisMObject())
        this_node_name = this_node.name()
        static_context = context.getStatic(this_node, sequences)

        job_values = job_attributes.getValues(data, self.aJob)
        render_values = task_attributes.getValues(data, self.aRenderTask)
        main_sequence = sequences["main_sequence"]
        scout_sequence = sequences["scout_sequence"] or []

        # Generate context with the first chunk for the job and other single tasks so that users don't get confused when they accidentally use a dynamic token, such as `start`, when the particular field is not in a series task.
        chunk = main_sequence.chunks()[0]
        dynamic_context = context.getDynamic(static_context, chunk)

        job = job_attributes.computeJob(job_values, context=dynamic_context)
        job.coords({"step": 2, "order": 0})

        remote_module_env_amendments = [
            {"key": "[MAYA_MODULE_PATH]", "value": "{remotemodule}"},
            {"key": "[PATH]", "value": "{remotemodule}/bin"},
        ]

        render_tasks = []
        for i, chunk in enumerate(main_sequence.chunks()):
            dynamic_context = context.getDynamic(static_context, chunk)
            render_task = task_attributes.computeTask(
                render_values,
                context=dynamic_context,
                env_amendments=remote_module_env_amendments,
            )
            render_task.coords({"step": 1, "order": i})
            if scout_sequence:
                if chunk.intersects(scout_sequence):
                    render_task.status("open")
                else:
                    render_task.status("holding")
            job.add(render_task)
            render_tasks.append(render_task)

        render_assets = assets.scrape_maya_assets(this_node_name)
        render_assets += assets.scrape_remote_module(this_node_name)
        render_assets += render_values["extra_assets"]
        upload_helpers.create_and_connect_upload_node(render_tasks, render_assets)

        return job
